@@ -3,7 +3,8 @@ from typing import Any, Callable, List, Optional, Dict, Union
 import numpy as np  # type: ignore
 from dataclasses import dataclass, field
 
-from code_loader.contract.decoder_classes import LeapImage, LeapText, LeapNumeric, LeapGraph
+from code_loader.contract.decoder_classes import LeapImage, LeapText, LeapNumeric, LeapGraph, LeapHorizontalBar, \
+    LeapMask
 from code_loader.contract.enums import DataStateType, DatasetInputType, DatasetOutputType, DatasetMetadataType, \
     DataStateEnum
 
@@ -27,9 +28,13 @@ DecoderCallableInterface = Union[
     Callable[[np.array], LeapImage],
     Callable[[np.array], LeapNumeric],
     Callable[[np.array], LeapText],
-    Callable[[np.array], LeapGraph]
+    Callable[[np.array], LeapGraph],
+    Callable[[np.array], LeapHorizontalBar],
+    Callable[[np.array], LeapMask],
 ]
 
+DecoderCallableReturnType = Union[LeapImage, LeapNumeric, LeapText, LeapGraph, LeapHorizontalBar, LeapMask]
+
 
 @dataclass
 class DecoderHandler:
@@ -51,17 +56,13 @@ class InputHandler(DatasetBaseHandler):
     shape: Optional[List[int]] = None
 
 
-
 @dataclass
 class GroundTruthHandler(DatasetBaseHandler):
     type: DatasetOutputType
     decoder_name: str
-    labels: Optional[List[str]] = None
-    masked_input: Optional[str] = None
     shape: Optional[List[int]] = None
 
 
-
 @dataclass
 class MetadataHandler(DatasetBaseHandler):
     type: DatasetMetadataType
