@@ -21,6 +21,7 @@ class DatasetBaseSectionInstance:
 class DatasetInputInstance(DatasetBaseSectionInstance):
     shape: List[int]
     type: DatasetInputType
+    decoder_name: str
 
 
 @dataclass
@@ -32,8 +33,7 @@ class DatasetMetadataInstance(DatasetBaseSectionInstance):
 class DatasetOutputInstance(DatasetBaseSectionInstance):
     shape: List[int]
     type: DatasetOutputType
-    masked_input: Optional[str] = None
-    labels: Optional[List[str]] = None
+    decoder_name: str
 
 
 @dataclass
@@ -56,5 +56,5 @@ class DatasetTestResultPayload:
 class DatasetIntegParseResult:
     payloads: List[DatasetTestResultPayload]
     is_valid: bool
-    setup: Optional[DatasetSetup] = None
-    general_error: Optional[str] = None
+    setup: Optional[DatasetSetup]
+    general_error: Optional[str]
