@@ -4,7 +4,7 @@ from typing import Dict, List, Iterable, Any
 import numpy as np  # type: ignore
 
 from code_loader.contract.datasetclasses import DatasetSample, DatasetBaseHandler, InputHandler, \
-    GroundTruthHandler, PreprocessResponse
+    GroundTruthHandler, PreprocessResponse, DecoderHandler, DecoderCallableReturnType
 from code_loader.contract.enums import DataStateEnum, TestingSectionEnum, DataStateType
 from code_loader.contract.responsedataclasses import DatasetIntegParseResult, DatasetTestResultPayload, \
     DatasetPreprocess, DatasetSetup, DatasetInputInstance, DatasetOutputInstance, DatasetMetadataInstance
@@ -25,6 +25,14 @@ class DatasetLoader:
         global_variables: Dict[Any, Any] = {}
         exec(self.dataset_script, global_variables)
 
+    @lru_cache()
+    def _decoder_by_name(self) -> Dict[str, DecoderHandler]:
+        setup = global_dataset_binder.setup_container
+        return {
+            decoder_handler.name: decoder_handler
+            for decoder_handler in setup.decoders
+        }
+
     def get_sample(self, state: DataStateEnum, idx: int) -> DatasetSample:
         self.exec_script()
         sample = DatasetSample(inputs=self._get_inputs(state, idx),
@@ -111,6 +119,16 @@ class DatasetLoader:
         all_dataset_base_handlers.extend(global_dataset_binder.setup_container.metadata)
         return all_dataset_base_handlers
 
+    def run_decoder(self, decoder_name: str, input_tensor: np.array
+                    ) -> DecoderCallableReturnType:
+        return self._decoder_by_name()[decoder_name].function(input_tensor)
+
+    def run_heatmap_decoder(self, decoder_name: str, input_heatmap: np.array) -> np.array:
+        heatmap_function = self._decoder_by_name()[decoder_name].heatmap_function
+        if heatmap_function is None:
+            return input_heatmap
+        return heatmap_function(input_heatmap)
+
     @staticmethod
     def get_dataset_setup_response() -> DatasetSetup:
         setup = global_dataset_binder.setup_container
@@ -124,15 +142,14 @@ class DatasetLoader:
         for inp in setup.inputs:
             if inp.shape is None:
                 raise Exception(f"cant calculate shape for input, input name:{inp.name}, input type:{inp.type}")
-            inputs.append(DatasetInputInstance(name=inp.name, shape=inp.shape, type=inp.type))
+            inputs.append(DatasetInputInstance(name=inp.name, shape=inp.shape, type=inp.type, decoder_name=inp.decoder_name))
 
         ground_truths = []
         for gt in setup.ground_truths:
             if gt.shape is None:
                 raise Exception(f"cant calculate shape for ground truth, gt name:{gt.name}, gt type:{gt.type}")
             ground_truths.append(
-                DatasetOutputInstance(name=gt.name, shape=gt.shape, type=gt.type,
-                                      masked_input=gt.masked_input, labels=gt.labels))
+                DatasetOutputInstance(name=gt.name, shape=gt.shape, type=gt.type, decoder_name=gt.decoder_name))
 
         metadata = [DatasetMetadataInstance(name=metadata.name, type=metadata.type)
                     for metadata in setup.metadata]
